@@ -41,7 +41,6 @@ class LanzouDirectory(BaseTable):
                 "name": _dir.name,
                 "path": _path,
                 "isfile": 0,
-                "downs": _dir.downs,
                 "desc": share.desc,
                 "url": share.url,
                 "pwd": share.pwd
@@ -55,13 +54,13 @@ class LanzouDirectory(BaseTable):
             _path = f'{path}/{_file.name}'
             if self.file_exist(_path):
                 continue
-            share = self.drive.get_share_info(fid=_dir.id, is_file=True)
+            share = self.drive.get_share_info(fid=_file.id, is_file=True)
             data = {
                 "fid": _file.id,
                 "name": _file.name,
                 "path": _path,
                 "isfile": 1,
-                "downs": _dir.downs,
+                "downs": _file.downs,
                 "desc": share.desc,
                 "url": share.url,
                 "pwd": share.pwd
